package com.ruoyi.system.service.impl.projectV2;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.projectV2.ZsyzLcjlMapper;
import com.ruoyi.system.domain.projectV2.ZsyzLcjl;
import com.ruoyi.system.service.projectV2.IZsyzLcjlService;

/**
 * 招商引资_流程记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-02-27
 */
@Service
public class ZsyzLcjlServiceImpl implements IZsyzLcjlService 
{
    @Autowired
    private ZsyzLcjlMapper zsyzLcjlMapper;

    /**
     * 查询招商引资_流程记录
     * 
     * @param id 招商引资_流程记录主键
     * @return 招商引资_流程记录
     */
    @Override
    public ZsyzLcjl selectZsyzLcjlById(Long id)
    {
        return zsyzLcjlMapper.selectZsyzLcjlById(id);
    }

    /**
     * 查询招商引资_流程记录列表
     * 
     * @param zsyzLcjl 招商引资_流程记录
     * @return 招商引资_流程记录
     */
    @Override
    public List<ZsyzLcjl> selectZsyzLcjlList(ZsyzLcjl zsyzLcjl)
    {
        return zsyzLcjlMapper.selectZsyzLcjlList(zsyzLcjl);
    }

    /**
     * 新增招商引资_流程记录
     * 
     * @param zsyzLcjl 招商引资_流程记录
     * @return 结果
     */
    @Override
    public int insertZsyzLcjl(ZsyzLcjl zsyzLcjl)
    {
        zsyzLcjl.setCreateTime(DateUtils.getNowDate());
        return zsyzLcjlMapper.insertZsyzLcjl(zsyzLcjl);
    }

    /**
     * 修改招商引资_流程记录
     * 
     * @param zsyzLcjl 招商引资_流程记录
     * @return 结果
     */
    @Override
    public int updateZsyzLcjl(ZsyzLcjl zsyzLcjl)
    {
        zsyzLcjl.setUpdateTime(DateUtils.getNowDate());
        return zsyzLcjlMapper.updateZsyzLcjl(zsyzLcjl);
    }

    /**
     * 批量删除招商引资_流程记录
     * 
     * @param ids 需要删除的招商引资_流程记录主键
     * @return 结果
     */
    @Override
    public int deleteZsyzLcjlByIds(Long[] ids)
    {
        return zsyzLcjlMapper.deleteZsyzLcjlByIds(ids);
    }

    /**
     * 删除招商引资_流程记录信息
     * 
     * @param id 招商引资_流程记录主键
     * @return 结果
     */
    @Override
    public int deleteZsyzLcjlById(Long id)
    {
        return zsyzLcjlMapper.deleteZsyzLcjlById(id);
    }
}
